@@ -1,13 +1,8 @@
 /*
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-*/
+    SPDX-License-Identifier: GPL-2.0-or-later
 
-/*
-  Copyright (C) 2005 Renchi Raju <renchi@pooh.tam.uiuc.edu>
-  Copyright (C) 2006, 2016 Peter Simonsson <peter.simonsson@gmail.com>
+    SPDX-FileCopyrightText: 2005 Renchi Raju <renchi@pooh.tam.uiuc.edu>
+    SPDX-FileCopyrightText: 2006, 2016 Peter Simonsson <peter.simonsson@gmail.com>
 */
 
 #ifndef SEARCHBAR_H
@@ -40,10 +35,15 @@ class SearchBar : public QWidget, private Ui::SearchBarBase
 
         bool eventFilter(QObject* object, QEvent* e) override;
 
+    Q_SIGNALS:
+        void signalSearchChanged(const QString& pattern);
+        void signalSearchNext();
+        void signalSearchPrevious();
+        void hidden();
+
     protected:
         void showEvent(QShowEvent* e) override;
         void hideEvent(QHideEvent* e) override;
-        bool focusedChild();
 
     private Q_SLOTS:
         void slotTextChanged();
@@ -54,11 +54,8 @@ class SearchBar : public QWidget, private Ui::SearchBarBase
         void toggleMatchCase(bool value);
         void toggleWholeWords(bool value);
 
-    Q_SIGNALS:
-        void signalSearchChanged(const QString& pattern);
-        void signalSearchNext();
-        void signalSearchPrevious();
-        void hidden();
+    private:
+        bool focusedChild() const;
 
     private:
         QTimer* m_timer;
@@ -71,6 +68,8 @@ class SearchBar : public QWidget, private Ui::SearchBarBase
         bool m_fromCursor;
 
         QShortcut* m_closeShortcut;
+
+        Q_DISABLE_COPY(SearchBar)
 };
 
 #endif                                            /* SEARCHBAR_H */
