@@ -29,12 +29,12 @@ namespace Konversation
 
     void TrayIcon::hideWindow()
     {
-        hideAssociatedWidget();
+        hideAssociatedWindow();
     }
 
     void TrayIcon::restoreWindow()
     {
-        if (associatedWidget()->isVisible())
+        if (associatedWindow()->isVisible())
             return;
         activate(QPoint());
     }
